# `physicsfront.qiskit`

This python package is essentially a utility package around IBM `qiskit`.
For example `physicsfront.qiskit.colab` supports initializing the IBM Quantum
account in the Google Colab environment.  In addition, `physicsfront.qiskit`
provides some utility functions for running jobs in `qiskit`.

## Installation

`pip install physicsfront-qiskit`
